@@ -21,16 +21,16 @@ import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.LinkedList;
 import java.util.List;
 
-import javax.servlet.ServletException;
+import jakarta.servlet.ServletException;
 
 import org.apache.catalina.connector.Request;
 import org.apache.catalina.connector.Response;
 import org.apache.catalina.util.NetMask;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.util.buf.StringUtils;
 
 public final class RemoteCIDRValve extends RequestFilterValve {
 
@@ -57,7 +57,8 @@ public final class RemoteCIDRValve extends RequestFilterValve {
     /**
      * Return a string representation of the {@link NetMask} list in #allow.
      *
-     * @return the #allow list as a string, without the leading '[' and trailing ']'
+     * @return the #allow list as a string, without the leading '[' and trailing
+     *         ']'
      */
     @Override
     public String getAllow() {
@@ -66,10 +67,10 @@ public final class RemoteCIDRValve extends RequestFilterValve {
 
 
     /**
-     * Fill the #allow list with the list of netmasks provided as an argument, if any. Calls #fillFromInput.
+     * Fill the #allow list with the list of netmasks provided as an argument,
+     * if any. Calls #fillFromInput.
      *
      * @param input The list of netmasks, as a comma separated string
-     *
      * @throws IllegalArgumentException One or more netmasks are invalid
      */
     @Override
@@ -92,7 +93,8 @@ public final class RemoteCIDRValve extends RequestFilterValve {
     /**
      * Return a string representation of the {@link NetMask} list in #deny.
      *
-     * @return the #deny list as a string, without the leading '[' and trailing ']'
+     * @return the #deny list as a string, without the leading '[' and trailing
+     *         ']'
      */
     @Override
     public String getDeny() {
@@ -101,10 +103,10 @@ public final class RemoteCIDRValve extends RequestFilterValve {
 
 
     /**
-     * Fill the #deny list with the list of netmasks provided as an argument, if any. Calls #fillFromInput.
+     * Fill the #deny list with the list of netmasks provided as an argument, if
+     * any. Calls #fillFromInput.
      *
      * @param input The list of netmasks, as a comma separated string
-     *
      * @throws IllegalArgumentException One or more netmasks are invalid
      */
     @Override
@@ -133,7 +135,8 @@ public final class RemoteCIDRValve extends RequestFilterValve {
             property = request.getRequest().getRemoteAddr();
         }
         if (getAddConnectorPort()) {
-            property = property + ";" + request.getConnector().getPortWithOffset();
+            property = property + ";" +
+                request.getConnector().getPortWithOffset();
         }
         process(property, request, response);
     }
@@ -203,8 +206,12 @@ public final class RemoteCIDRValve extends RequestFilterValve {
         }
 
         // Allow if deny is specified but allow isn't
-        // Otherwise deny this request
-        return !deny.isEmpty() && allow.isEmpty();
+        if (!deny.isEmpty() && allow.isEmpty()) {
+            return true;
+        }
+
+        // Deny this request
+        return false;
     }
 
 
@@ -215,12 +222,11 @@ public final class RemoteCIDRValve extends RequestFilterValve {
 
 
     /**
-     * Fill a {@link NetMask} list from a string input containing a comma-separated list of (hopefully valid)
-     * {@link NetMask}s.
+     * Fill a {@link NetMask} list from a string input containing a
+     * comma-separated list of (hopefully valid) {@link NetMask}s.
      *
-     * @param input  The input string
+     * @param input The input string
      * @param target The list to fill
-     *
      * @return a string list of processing errors (empty when no errors)
      */
 
@@ -230,10 +236,10 @@ public final class RemoteCIDRValve extends RequestFilterValve {
             return Collections.emptyList();
         }
 
-        final List<String> messages = new ArrayList<>();
+        final List<String> messages = new LinkedList<>();
         NetMask nm;
 
-        for (final String s : StringUtils.splitCommaSeparated(input)) {
+        for (final String s : input.split("\\s*,\\s*")) {
             try {
                 nm = new NetMask(s);
                 target.add(nm);
