@@ -20,8 +20,8 @@ import java.beans.PropertyEditorManager;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 
-import javax.el.ELException;
-import javax.el.ELManager;
+import jakarta.el.ELException;
+import jakarta.el.ELManager;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -236,15 +236,13 @@ public class TestELSupport {
 
     @Test
     public void testCoerceToNumber01() {
-        Object result = ELSupport.coerceToNumber(
-                null, (Object) null, Integer.class);
+        Object result = ELSupport.coerceToNumber(null, null, Integer.class);
         Assert.assertNull("Result: " + result, result);
     }
 
     @Test
     public void testCoerceToNumber02() {
-        Object result = ELSupport.coerceToNumber(
-                null, (Object) null, int.class);
+        Object result = ELSupport.coerceToNumber(null, null, int.class);
         Assert.assertEquals(Integer.valueOf(0), result);
     }
 
